##  Antipatterns
This section addresses antipatterns involving ineffective or counterproductive ways of modeling initiatives in SAP LeanIX.
  * Don’t use deep hierarchies so that you can keep maintenance efforts low. Instead, show initiatives on an aggregated level (synchronized with a project portfolio management tool).
